Crate tower_sesh

A Tower middleware for strongly typed, efficient sessions.

🚧 UNDER CONSTRUCTION 🚧

This crate is being actively developed. Its public API is open to change at any time.

To track development of this crate, visit its GitHub repository.

Modules

config
Cookie configuration.
middleware
session
store
value
The Value enum, a loosely typed way of representing any session value.

Structs

Session
Extractor to read and mutate session data.
SessionLayer
A layer that provides Session as a request extension.

Enums

Value
A loosely typed value that can be stored in a session.