Enum SameSite

#[non_exhaustive]
pub enum SameSite { Strict, Lax, None, }
The SameSite cookie attribute.

A cookie with a SameSite attribute is imposed restrictions on when it is sent to the origin server in a cross-site request:

  • Strict: The cookie is never sent in cross-site requests.
  • Lax: The cookie is sent in cross-site top-level navigations.
  • None: The cookie is sent in all cross-site requests if the Secure flag is also set; otherwise, the cookie is ignored.

Note: This cookie attribute is an HTTP draft! Its meaning and definition are subject to change.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Strict



Lax



None