Module session

Structs

OptionSessionGuard
A RAII mutex guard holding a lock to a mutex contained in Session<T>. The data Option<T> can be accessed through this guard via its Deref and DerefMut implementations.
Session
Extractor to read and mutate session data.
SessionGuard
A RAII mutex guard holding a lock to a mutex contained in Session<T>. The data T can be accessed through this guard via its Deref and DerefMut implementations.
SessionRejectionaxum
Rejection for Session if an unrecoverable error occurred when loading the session.