Trait SessionStore

pub trait SessionStore<T>:
    'static
    + Send
    + Sync
    + SessionStoreImpl<T> { }
Backing storage for session data.

This trait is sealed and intended to be opaque. The details of this trait are open to change across non-major version bumps; as such, depending on them may cause breakage.

Implementors

Source

impl<T> SessionStore<T> for MemoryStore<T>
where T: 'static + Send + Sync + Clone,

Source

impl<T, Cache: SessionStore<T>, Store: SessionStore<T>> SessionStore<T> for CachingStore<T, Cache, Store>
where T: 'static + Send + Sync,