Module value

The Value enum, a loosely typed way of representing any session value.

For more information, see the documentation for Value.

Re-exports

pub use self::map::Map;

Modules

map
A map of String to Value.

Structs

Error
Number
Represents a number, whether integer or floating point.

Enums

Value
A loosely typed value that can be stored in a session.

Traits

Index
A type that can be used to index into a Value.