Module map

A map of String to Value.

Structs

IntoIter
An owning iterator over the entries of a Map.
IntoValues
An owning iterator over the values of a Map.
Iter
An iterator over the entries of a Map.
IterMut
A mutable iterator over the entries of a Map.
Keys
An iterator over the keys of a Map.
Map
Represents a serializable key/value type.
OccupiedEntry
A view into an occupied entry in a Map. It is part of the Entry enum.
VacantEntry
A view into a vacant entry in a Map. It is part of the Entry enum.
Values
An iterator over the values of a Map.
ValuesMut
A mutable iterator over the values of a Map.

Enums

Entry
A view into a single entry in a map, which may be either vacant or occupied.