Struct OccupiedEntry

pub struct OccupiedEntry<'a> { /* private fields */ }
A view into an occupied entry in a Map. It is part of the Entry enum.

Implementations

Source

impl<'a> OccupiedEntry<'a>

pub fn key(&self) -> &String

Gets a reference to the key in the entry.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from(12));

match map.entry("sesh") {
    Entry::Occupied(occupied) => {
        assert_eq!(occupied.key(), &"sesh");
    }
    Entry::Vacant(_) => unimplemented!(),
}
pub fn get(&self) -> &Value

Gets a reference to the value in the entry.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from(12));

match map.entry("sesh") {
    Entry::Occupied(occupied) => {
        assert_eq!(occupied.get(), 12);
    }
    Entry::Vacant(_) => unimplemented!(),
}
pub fn get_mut(&mut self) -> &mut Value

Gets a mutable reference to the value in the entry.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from([1, 2, 3]));

match map.entry("sesh") {
    Entry::Occupied(mut occupied) => {
        occupied.get_mut().as_array_mut().unwrap().push(Value::from(4));
    }
    Entry::Vacant(_) => unimplemented!(),
}

assert_eq!(map["sesh"].as_array().unwrap().len(), 4);
pub fn into_mut(self) -> &'a mut Value

Converts the entry into a mutable reference to its value.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from([1, 2, 3]));

match map.entry("sesh") {
    Entry::Occupied(mut occupied) => {
        occupied.into_mut().as_array_mut().unwrap().push(Value::from(4));
    }
    Entry::Vacant(_) => unimplemented!(),
}

assert_eq!(map["sesh"].as_array().unwrap().len(), 4);
pub fn remove(self) -> Value

Takes the value of the entry out of the map, and returns it.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from(12));

match map.entry("sesh") {
    Entry::Occupied(occupied) => {
        assert_eq!(occupied.remove(), 12);
    }
    Entry::Vacant(_) => unimplemented!(),
}
pub fn remove_entry(self) -> (String, Value)

Removes the entry from the map, returning the stored key and value.

Examples
use tower_sesh::value::{map::Entry, Map, Value};

let mut map = Map::new();
map.insert("sesh".to_owned(), Value::from(12));

match map.entry("sesh") {
    Entry::Occupied(occupied) => {
        let (key, value) = occupied.remove_entry();
        assert_eq!(key, "sesh");
        assert_eq!(value, 12);
    }
    Entry::Vacant(_) => unimplemented!(),
}