pub struct VacantEntry<'a> { /* private fields */ }Expand description
A view into a vacant entry in a Map.
It is part of the Entry enum.
Implementations
Sourceimpl<'a> VacantEntry<'a>
impl<'a> VacantEntry<'a>
Sourcepub fn key(&self) -> &String
pub fn key(&self) -> &String
Gets a reference to the key that would be used when inserting a value
through the VacantEntry.
Examples
use tower_sesh::value::{map::Entry, Map};
let mut map = Map::new();
match map.entry("sesh") {
Entry::Vacant(vacant) => {
assert_eq!(vacant.key(), &"sesh");
}
Entry::Occupied(_) => unimplemented!(),
}Sourcepub fn insert(self, value: Value) -> &'a mut Value
pub fn insert(self, value: Value) -> &'a mut Value
Sets the value of the entry with the VacantEntry’s key, and returns a
mutable reference to it.
Examples
use tower_sesh::value::{map::Entry, Map, Value};
let mut map = Map::new();
match map.entry("sesh") {
Entry::Vacant(vacant) => {
vacant.insert(Value::from("hoho"));
}
Entry::Occupied(_) => unimplemented!(),
}Trait Implementations