A RAII mutex guard holding a lock to a mutex contained in Session<T>. The
data Option<T> can be accessed through this guard via its Deref and
DerefMut implementations.
A RAII mutex guard holding a lock to a mutex contained in Session<T>. The
data T can be accessed through this guard via its Deref and
DerefMut implementations.