The Value enum, a loosely typed way of representing any session value.
For more information, see the documentation for Value.
Re-exports
pub use self::map::Map;
Modules
Structs
Enums
- Value
- A loosely typed value that can be stored in a session.